@@ -6,23 +6,24 @@ use {
 #[derive(Accounts)]
 #[instruction(bump: u8, target: Pubkey)]
 pub struct CreateClaimReceiptCtx<'info> {
-    #[account(mut)]
     token_manager: Box<Account<'info, TokenManager>>,
 
-    #[account(mut, constraint =
-        token_manager.claim_authority != None
-        && token_manager.claim_authority.unwrap() == claim_authority.key()
+    #[account(constraint =
+        token_manager.claim_approver != None
+        && token_manager.claim_approver.unwrap() == claim_approver.key()
         @ ErrorCode::InvalidIssuer
     )]
-    claim_authority: Signer<'info>,
+    claim_approver: Signer<'info>,
 
     #[account(
         init,
-        payer = claim_authority,
+        payer = payer,
         seeds = [CLAIM_RECEIPT_SEED.as_bytes(), token_manager.key().as_ref(), target.key().as_ref()], bump = bump,
         space = CLAIM_RECEIPT_SIZE,
     )]
     claim_receipt: Box<Account<'info, ClaimReceipt>>,
+    #[account(mut)]
+    payer: Signer<'info>,
     system_program: Program<'info, System>,
 }
 
